#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.core.container.api.ContainerSubscriptionModel import ContainerSubscriptionModel
from netbluemind.core.container.api.ContainerSubscriptionModel import __ContainerSubscriptionModelSerDer__
class ContainerSubscriptionDescriptor (ContainerSubscriptionModel):
    def __init__( self):
        ContainerSubscriptionModel.__init__(self)
        self.ownerDisplayName = None
        self.ownerDirEntryPath = None
        pass

class __ContainerSubscriptionDescriptorSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = ContainerSubscriptionDescriptor()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        __ContainerSubscriptionModelSerDer__().parseInternal(value,instance)
        ownerDisplayNameValue = value['ownerDisplayName']
        instance.ownerDisplayName = serder.STRING.parse(ownerDisplayNameValue)
        ownerDirEntryPathValue = value['ownerDirEntryPath']
        instance.ownerDirEntryPath = serder.STRING.parse(ownerDirEntryPathValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):
        __ContainerSubscriptionModelSerDer__().encodeInternal(value,instance)

        ownerDisplayNameValue = value.ownerDisplayName
        instance["ownerDisplayName"] = serder.STRING.encode(ownerDisplayNameValue)
        ownerDirEntryPathValue = value.ownerDirEntryPath
        instance["ownerDirEntryPath"] = serder.STRING.encode(ownerDirEntryPathValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.addressbook.api.VCardBasicAttribute import VCardBasicAttribute
from netbluemind.addressbook.api.VCardBasicAttribute import __VCardBasicAttributeSerDer__
class VCardIdentificationName (VCardBasicAttribute):
    def __init__( self):
        VCardBasicAttribute.__init__(self)
        self.familyNames = None
        self.givenNames = None
        self.additionalNames = None
        self.prefixes = None
        self.suffixes = None
        pass

class __VCardIdentificationNameSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = VCardIdentificationName()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        __VCardBasicAttributeSerDer__().parseInternal(value,instance)
        familyNamesValue = value['familyNames']
        instance.familyNames = serder.STRING.parse(familyNamesValue)
        givenNamesValue = value['givenNames']
        instance.givenNames = serder.STRING.parse(givenNamesValue)
        additionalNamesValue = value['additionalNames']
        instance.additionalNames = serder.STRING.parse(additionalNamesValue)
        prefixesValue = value['prefixes']
        instance.prefixes = serder.STRING.parse(prefixesValue)
        suffixesValue = value['suffixes']
        instance.suffixes = serder.STRING.parse(suffixesValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):
        __VCardBasicAttributeSerDer__().encodeInternal(value,instance)

        familyNamesValue = value.familyNames
        instance["familyNames"] = serder.STRING.encode(familyNamesValue)
        givenNamesValue = value.givenNames
        instance["givenNames"] = serder.STRING.encode(givenNamesValue)
        additionalNamesValue = value.additionalNames
        instance["additionalNames"] = serder.STRING.encode(additionalNamesValue)
        prefixesValue = value.prefixes
        instance["prefixes"] = serder.STRING.encode(prefixesValue)
        suffixesValue = value.suffixes
        instance["suffixes"] = serder.STRING.encode(suffixesValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.calendar.api.VEvent import VEvent
from netbluemind.calendar.api.VEvent import __VEventSerDer__
class VEventOccurrence (VEvent):
    def __init__( self):
        VEvent.__init__(self)
        self.recurid = None
        pass

class __VEventOccurrenceSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = VEventOccurrence()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        __VEventSerDer__().parseInternal(value,instance)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        recuridValue = value['recurid']
        instance.recurid = __BmDateTimeSerDer__().parse(recuridValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):
        __VEventSerDer__().encodeInternal(value,instance)

        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        recuridValue = value.recurid
        instance["recurid"] = __BmDateTimeSerDer__().encode(recuridValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class SubscriptionInformationsInstallationIndicator :
    def __init__( self):
        self.kind = None
        self.maxValue = None
        self.currentValue = None
        self.expiration = None
        pass

class __SubscriptionInformationsInstallationIndicatorSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = SubscriptionInformationsInstallationIndicator()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.system.api.SubscriptionInformationsInstallationIndicatorKind import SubscriptionInformationsInstallationIndicatorKind
        from netbluemind.system.api.SubscriptionInformationsInstallationIndicatorKind import __SubscriptionInformationsInstallationIndicatorKindSerDer__
        kindValue = value['kind']
        instance.kind = __SubscriptionInformationsInstallationIndicatorKindSerDer__().parse(kindValue)
        maxValueValue = value['maxValue']
        instance.maxValue = serder.INT.parse(maxValueValue)
        currentValueValue = value['currentValue']
        instance.currentValue = serder.INT.parse(currentValueValue)
        expirationValue = value['expiration']
        instance.expiration = serder.DATE.parse(expirationValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.system.api.SubscriptionInformationsInstallationIndicatorKind import SubscriptionInformationsInstallationIndicatorKind
        from netbluemind.system.api.SubscriptionInformationsInstallationIndicatorKind import __SubscriptionInformationsInstallationIndicatorKindSerDer__
        kindValue = value.kind
        instance["kind"] = __SubscriptionInformationsInstallationIndicatorKindSerDer__().encode(kindValue)
        maxValueValue = value.maxValue
        instance["maxValue"] = serder.INT.encode(maxValueValue)
        currentValueValue = value.currentValue
        instance["currentValue"] = serder.INT.encode(currentValueValue)
        expirationValue = value.expiration
        instance["expiration"] = serder.DATE.encode(expirationValue)
        return instance

